@@ -14,7 +14,7 @@ def after_log() -> Callable[["RetryCallState"], None]:
 
             args[0]._log.warning(
                 f"Finished call to '{_utils.get_callback_name(retry_state.fn)}' "
-                f"after {'%0.3f' % retry_state.seconds_since_start}(s), "  # noqa: S001
+                f"after {retry_state.seconds_since_start}(s), "
                 f"this was the {_utils.to_ordinal(retry_state.attempt_number)} time calling it.",
             )
 
