@@ -9,12 +9,12 @@ from nautilus_trader.common.logging import Logger
 from nautilus_trader.core.correctness import PyCondition
 from nautilus_trader.core.uuid import UUID4
 from nautilus_trader.live.data_client import LiveMarketDataClient
-from nautilus_trader.model.c_enums.bar_aggregation import BarAggregationParser
 from nautilus_trader.model.data.bar import BarType
 from nautilus_trader.model.data.base import DataType
 from nautilus_trader.model.data.tick import QuoteTick
 from nautilus_trader.model.data.tick import TradeTick
 from nautilus_trader.model.enums import BarAggregation
+from nautilus_trader.model.enums import BarAggregationParser
 from nautilus_trader.model.enums import BookType
 from nautilus_trader.model.enums import PriceType
 from nautilus_trader.model.identifiers import ClientId
@@ -46,7 +46,7 @@ from nacre.adapters.zb.parsing import parse_ticker_ws
 from nacre.adapters.zb.parsing import parse_trade_tick
 from nacre.adapters.zb.parsing import parse_trade_tick_ws
 from nacre.adapters.zb.providers import ZbInstrumentProvider
-from nacre.adapters.zb.websocket.future import ZbFuturesWebSocket
+from nacre.adapters.zb.websocket.futures import ZbFuturesWebsocketClient
 from nacre.adapters.zb.websocket.spot import ZbSpotWebSocket
 from nacre.model.data.tick import MarkTick
 
@@ -71,9 +71,9 @@ class ZbDataClient(LiveMarketDataClient):
         if not self._client.connected:
             await self._client.connect()
         try:
-            await self._instrument_provider.load_all_or_wait_async()
+            await self._instrument_provider.initialize()
         except ZbError as ex:
-            self._log.exception(ex)
+            self._log.exception("Error on connecting", ex)
             return
 
         self._send_all_instruments_to_data_engine()
@@ -105,14 +105,14 @@ class ZbDataClient(LiveMarketDataClient):
             self._log.debug("Canceling `update_instruments` task...")
             self._update_instruments_task.cancel()
 
-        # Disconnect WebSocket clients
-        if self._ws_api.is_connected:
-            await self._ws_api.disconnect()
-
         # Disconnect HTTP client
         if self._client.connected:
             await self._client.disconnect()
 
+        # Disconnect WebSocket clients
+        if self._ws_api.is_connected:
+            await self._ws_api.disconnect()
+
         self._set_connected(False)
         self._log.info("Disconnected.")
 
@@ -283,6 +283,7 @@ class ZbSpotDataClient(ZbDataClient):
         logger: Logger,
         venue: Venue,
         instrument_provider: ZbInstrumentProvider,
+        base_url_ws: Optional[str] = None,
     ):
         # HTTP API
         self._market_api = ZbSpotMarketHttpAPI(client=client)
@@ -292,10 +293,13 @@ class ZbSpotDataClient(ZbDataClient):
             clock=clock,
             logger=logger,
             handler=self._handle_ws_message,
+            base_url=base_url_ws,
         )
+
         super(ZbDataClient, self).__init__(
             loop=loop,
             client_id=ClientId(venue.value),
+            venue=venue,
             instrument_provider=instrument_provider,
             msgbus=msgbus,
             cache=cache,
@@ -537,20 +541,23 @@ class ZbFutureDataClient(ZbDataClient):
         logger: Logger,
         venue: Venue,
         instrument_provider: ZbInstrumentProvider,
+        base_url_ws: Optional[str] = None,
     ):
         # HTTP API
         self._market_api = ZbFutureMarketHttpAPI(client=client)
         # websocket api
-        self._ws_api = ZbFuturesWebSocket(
+        self._ws_api = ZbFuturesWebsocketClient(
             loop=loop,
             clock=clock,
             logger=logger,
             handler=self._handle_ws_message,
+            base_url=base_url_ws,
         )
 
         super(ZbDataClient, self).__init__(
             loop=loop,
             client_id=ClientId(venue.value),
+            venue=venue,
             instrument_provider=instrument_provider,
             msgbus=msgbus,
             cache=cache,
