@@ -1,30 +1,29 @@
 import asyncio
 import os
 from functools import lru_cache
-from typing import Any, Dict, Optional
+from typing import Dict, Optional, Union
 
 from nautilus_trader.cache.cache import Cache
 from nautilus_trader.common.clock import LiveClock
 from nautilus_trader.common.logging import LiveLogger
 from nautilus_trader.common.logging import Logger
+from nautilus_trader.config import InstrumentProviderConfig
 from nautilus_trader.live.factories import LiveDataClientFactory
-from nautilus_trader.live.factories import LiveExecutionClientFactory
+from nautilus_trader.live.factories import LiveExecClientFactory
 from nautilus_trader.model.identifiers import AccountId
 from nautilus_trader.model.identifiers import Venue
 from nautilus_trader.msgbus.bus import MessageBus
 
-from nacre.adapters.zb.data import ZbDataClient
+from nacre.adapters.zb.common.enums import ZbAccountType
+from nacre.adapters.zb.config import ZbDataClientConfig
+from nacre.adapters.zb.config import ZbExecClientConfig
 from nacre.adapters.zb.data import ZbFutureDataClient
 from nacre.adapters.zb.data import ZbSpotDataClient
-from nacre.adapters.zb.execution import ZbFutureExecutionClient
-from nacre.adapters.zb.execution import ZbSpotExecutionClient
-from nacre.adapters.zb.http.api.future_market import ZbFutureMarketHttpAPI
-from nacre.adapters.zb.http.api.spot_market import ZbSpotMarketHttpAPI
+from nacre.adapters.zb.futures.execution import ZbFuturesExecutionClient
 from nacre.adapters.zb.http.client import ZbHttpClient
 from nacre.adapters.zb.http.spot import ZbSpotHttpClient
-
-# from nacre.adapters.client.providers import ZB_VENUE
 from nacre.adapters.zb.providers import ZbInstrumentProvider
+from nacre.adapters.zb.spot.execution import ZbSpotExecutionClient
 
 
 HTTP_CLIENTS: Dict[str, ZbHttpClient] = {}
@@ -34,23 +33,20 @@ def get_cached_zb_http_client(
     loop: asyncio.AbstractEventLoop,
     clock: LiveClock,
     logger: Logger,
+    base_url: str,
     key: Optional[str] = None,
     sec: Optional[str] = None,
-    account_type: Optional[str] = None,
+    account_type: ZbAccountType = ZbAccountType.SPOT,
     proxy: Optional[str] = None,
-    type: str = "data",
 ) -> ZbHttpClient:
 
     global HTTP_CLIENTS
     key = key or os.environ.get("ZB_API_KEY", "")
     sec = sec or os.environ.get("ZB_API_SECRET", "")
-    account_type = account_type or "future"
 
-    client_key: str = "|".join((key, sec, account_type, str(proxy or "")))
+    client_key: str = "|".join((key, sec, account_type.value, str(proxy or "")))
     if client_key not in HTTP_CLIENTS:
-        base_url = None
-        if account_type == "future":
-            base_url = "https://fapi.zb.com"
+        if account_type.is_futures:
             client = ZbHttpClient(
                 loop=loop,
                 clock=clock,
@@ -61,14 +57,14 @@ def get_cached_zb_http_client(
                 timeout=10,
                 proxy=proxy,
             )
-        elif account_type == "spot":
+        elif account_type.is_spot:
             client = ZbSpotHttpClient(
                 loop=loop,
                 clock=clock,
                 logger=logger,
                 key=key,
                 secret=sec,
-                base_url="https://trade.zb.company" if type == "exec" else "https://api.zb.company",
+                base_url=base_url,
                 timeout=10,
                 proxy=proxy,
             )
@@ -83,14 +79,16 @@ def get_cached_zb_http_client(
 def get_cached_zb_instrument_provider(
     logger: Logger,
     venue: Venue,
-    market_api: ZbFutureMarketHttpAPI,
-    account_type: str,
+    client: ZbHttpClient,
+    account_type: ZbAccountType,
+    config: InstrumentProviderConfig,
 ) -> ZbInstrumentProvider:
     return ZbInstrumentProvider(
         logger=logger,
         venue=venue,
-        market_api=market_api,
+        client=client,
         account_type=account_type,
+        config=config,
     )
 
 
@@ -99,42 +97,41 @@ class ZbLiveDataClientFactory(LiveDataClientFactory):
     def create(
         loop: asyncio.AbstractEventLoop,
         name: str,
-        config: Dict[str, Any],
+        config: ZbDataClientConfig,
         msgbus: MessageBus,
         cache: Cache,
         clock: LiveClock,
         logger: LiveLogger,
-        client_cls=None,
-    ) -> ZbDataClient:
+    ) -> Union[ZbSpotDataClient, ZbFutureDataClient]:
+
+        base_url_http_default: str = _get_default_http_base_url(config)
+        base_url_ws_default: str = _get_default_ws_base_url(config)
 
-        proxy = config.get("httpProxy", None)
-        account_type_str = config.get("defaultType", "spot")
         client = get_cached_zb_http_client(
-            account_type=account_type_str,
             loop=loop,
             clock=clock,
             logger=logger,
-            proxy=proxy,
+            base_url=config.base_url_http or base_url_http_default,
+            key=config.api_key,
+            sec=config.api_secret,
+            account_type=config.account_type,
+            proxy=config.http_proxy,
         )
 
         venue = Venue(name.upper())
-        if account_type_str == "spot":
-            market_api = ZbSpotMarketHttpAPI(client=client)
-        elif account_type_str == "future":
-            market_api = ZbFutureMarketHttpAPI(client=client)
-        else:
-            raise ValueError(f"Account type not implemented: {account_type_str}")
+
         # Get instrument provider singleton
         provider = get_cached_zb_instrument_provider(
-            logger=logger,
             venue=venue,
-            market_api=market_api,
-            account_type=account_type_str,
+            client=client,
+            logger=logger,
+            account_type=config.account_type,
+            config=config.instrument_provider,
         )
 
         # Create client
-        if account_type_str == "spot":
-            data_client = ZbSpotDataClient(
+        if config.account_type.is_spot:
+            return ZbSpotDataClient(
                 loop=loop,
                 client=client,
                 msgbus=msgbus,
@@ -143,9 +140,10 @@ class ZbLiveDataClientFactory(LiveDataClientFactory):
                 logger=logger,
                 venue=venue,
                 instrument_provider=provider,
+                base_url_ws=config.base_url_ws or base_url_ws_default,
             )
-        elif account_type_str == "future":
-            data_client = ZbFutureDataClient(
+        elif config.account_type.is_futures:
+            return ZbFutureDataClient(
                 loop=loop,
                 client=client,
                 msgbus=msgbus,
@@ -154,46 +152,36 @@ class ZbLiveDataClientFactory(LiveDataClientFactory):
                 logger=logger,
                 venue=venue,
                 instrument_provider=provider,
+                base_url_ws=config.base_url_ws or base_url_ws_default,
             )
         else:
-            raise ValueError(f"Account type not implemented: {account_type_str}")
-
-        return data_client
+            raise ValueError(f"Account type not implemented: {config.account_type}")
 
 
-class ZbLiveExecutionClientFactory(LiveExecutionClientFactory):
+class ZbLiveExecClientFactory(LiveExecClientFactory):
     @staticmethod
     def create(
         loop: asyncio.AbstractEventLoop,
         name: str,
-        config,
+        config: ZbExecClientConfig,
         msgbus: MessageBus,
         cache: Cache,
         clock: LiveClock,
         logger: LiveLogger,
-        client_cls=None,
-    ):
+    ) -> Union[ZbSpotExecutionClient, ZbFuturesExecutionClient]:
+
+        base_url_http_default: str = _get_default_http_base_url(config)
+        base_url_ws_default: str = _get_default_ws_base_url(config)
 
-        proxy = config.get("httpProxy", None)
-        socks_proxy = config.get("socksProxy", None)
-        account_type_str = config.get("defaultType", "spot")
         client = get_cached_zb_http_client(
-            key=config.get("api_key"),
-            sec=config.get("api_secret"),
-            type="exec",
             loop=loop,
             clock=clock,
             logger=logger,
-            account_type=account_type_str,
-            proxy=proxy,
-        )
-
-        market_client = get_cached_zb_http_client(
-            account_type=account_type_str,
-            loop=loop,
-            clock=clock,
-            logger=logger,
-            # proxy=proxy,  # Normally market api doesn't require proxy
+            base_url=config.base_url_http or base_url_http_default,
+            key=config.api_key,
+            sec=config.api_secret,
+            account_type=config.account_type,
+            proxy=config.http_proxy,
         )
 
         res = name.partition("-")
@@ -203,48 +191,78 @@ class ZbLiveExecutionClientFactory(LiveExecutionClientFactory):
             account_id = AccountId(name, "DEFAULT")
         venue = Venue(account_id.issuer)
 
-        if account_type_str == "spot":
-            market_api = ZbSpotMarketHttpAPI(client=market_client)
-        elif account_type_str == "future":
-            market_api = ZbFutureMarketHttpAPI(client=market_client)
-        else:
-            raise ValueError(f"Account type not implemented: {account_type_str}")
+        market_client = client
+        # ZbSpot separate market and trade api to "api.zb.com" and "trade.zb.com"
+        if config.account_type.is_spot:
+            market_client = get_cached_zb_http_client(
+                loop=loop,
+                clock=clock,
+                logger=logger,
+                base_url="https://api.zb.com",  # Hardcode for now
+                account_type=config.account_type,
+            )
 
         provider = get_cached_zb_instrument_provider(
-            logger=logger,
             venue=venue,
-            market_api=market_api,
-            account_type=account_type_str,
+            client=market_client,
+            logger=logger,
+            account_type=config.account_type,
+            config=config.instrument_provider,
         )
 
-        if account_type_str == "spot":
-            exec_client = ZbSpotExecutionClient(
+        if config.account_type.is_spot:
+            return ZbSpotExecutionClient(
                 loop=loop,
                 client=client,
                 market_client=market_client,
                 name=name,
                 account_id=account_id,
+                venue=venue,
                 msgbus=msgbus,
                 cache=cache,
                 clock=clock,
                 logger=logger,
                 instrument_provider=provider,
-                socks_proxy=socks_proxy,
+                base_url_ws=config.base_url_ws or base_url_ws_default,
             )
-        elif account_type_str == "future":
-            exec_client = ZbFutureExecutionClient(
+        elif config.account_type.is_futures:
+            return ZbFuturesExecutionClient(
                 loop=loop,
                 client=client,
+                oms_type=config.oms_type,
                 name=name,
                 account_id=account_id,
+                venue=venue,
                 msgbus=msgbus,
                 cache=cache,
                 clock=clock,
                 logger=logger,
                 instrument_provider=provider,
-                socks_proxy=socks_proxy,
+                base_url_ws=config.base_url_ws or base_url_ws_default,
             )
         else:
-            raise ValueError(f"Account type not implemented: {account_type_str}")
+            raise ValueError(f"Account type not implemented: {config.account_type}")
 
-        return exec_client
+
+def _get_default_http_base_url(config: Union[ZbDataClientConfig, ZbExecClientConfig]) -> str:
+    if config.account_type == ZbAccountType.SPOT:
+        if isinstance(config, ZbDataClientConfig):
+            return "https://api.zb.com"
+        elif isinstance(config, ZbExecClientConfig):
+            return "https://trade.zb.com"
+    elif config.account_type == ZbAccountType.FUTURES_USDT:
+        return "https://fapi.zb.com"
+
+    raise RuntimeError(f"invalid Zb account type, was {config.account_type}")
+
+
+def _get_default_ws_base_url(config: Union[ZbDataClientConfig, ZbExecClientConfig]) -> str:
+    if config.account_type in (ZbAccountType.SPOT, ZbAccountType.MARGIN):
+        return "wss://api.zb.com/websocket"
+    elif config.account_type == ZbAccountType.FUTURES_USDT:
+        if isinstance(config, ZbDataClientConfig):
+            return "wss://fapi.zb.com/ws/public/v1"
+        elif isinstance(config, ZbExecClientConfig):
+            return "wss://fapi.zb.com/ws/private/api/v2"
+
+    raise RuntimeError(f"invalid Zb account type, was {config.account_type}")
