@@ -30,11 +30,10 @@ class ZbFutureMarketHttpAPI:
         self.client = client
 
     async def market_list(self) -> List[Dict]:
-        aws = [
+        results = await asyncio.gather(
             self.client.query(url_path="/Server/api/v2/" + "config/marketList"),
             self.client.query(url_path="/qc/Server/api/v2/" + "config/marketList"),
-        ]
-        results = await asyncio.gather(*aws)
+        )
         markets = []
         for res in results:
             markets.extend(res.get("data", []))
