@@ -86,3 +86,8 @@ class ZbSpotMarketHttpAPI:
             url_path=self.BASE_ENDPOINT + "kline",
             payload=payload,
         )
+
+    async def group_markets(self) -> Dict[str, Any]:
+        return await self.client.query(
+            url_path=self.BASE_ENDPOINT + "getGroupMarkets",
+        )
