@@ -22,8 +22,6 @@ from nacre.adapters.zb.http.error import ZbClientError
 from nacre.adapters.zb.http.error import ZbOperationError
 from nacre.adapters.zb.http.error import ZbServerError
 from nacre.adapters.zb.http.error import ZbSpotOperationError
-from nacre.metrics.metrics import HTTP_ERROR_COUNTER
-from nacre.metrics.metrics import REQ_TIME
 from nacre.network.http import HttpClient
 
 
@@ -68,7 +66,9 @@ class ZbHttpClient(HttpClient):
         )
         self._clock = clock
         self._key = key
-        self._hashed_secret = hashlib.sha1((secret or "").encode("utf-8")).hexdigest()  # noqa: S303
+        self._hashed_secret = hashlib.sha1(  # noqa: S303, S324
+            (secret or "").encode("utf-8")
+        ).hexdigest()
         self._base_url = base_url or self.BASE_URL
         self._show_limit_usage = show_limit_usage
         self._proxies = None
@@ -163,11 +163,7 @@ class ZbHttpClient(HttpClient):
                 kwargs["json"] = payload
                 kwargs.pop("params")
 
-            with REQ_TIME.labels(method=http_method, endpoint=kwargs["url"]).time():
-                with HTTP_ERROR_COUNTER.labels(
-                    method=http_method, endpoint=kwargs["url"]
-                ).count_exceptions():
-                    resp: ClientResponse = await self.request(**kwargs)
+            resp: ClientResponse = await self.request(**kwargs)
         except ClientResponseError as ex:
             await self._handle_exception(ex)
             return
