@@ -3,6 +3,13 @@ class ZbError(Exception):
     The base class for all `Zb` specific errors.
     """
 
+    def __init__(self, status, message):
+        self.status = status
+        self.message = message
+
+    def __repr__(self) -> str:
+        return f"{type(self).__name__}(" f"status={self.status}, " f"message={self.message})"
+
 
 class ZbServerError(ZbError):
     """
@@ -34,3 +41,13 @@ class ZbOperationError(ZbError):
     def __init__(self, status, message):
         self.status = status
         self.message = message
+
+
+class ZbSpotOperationError(ZbError):
+    """
+    Represents a `Zb` application logical error.
+    """
+
+    def __init__(self, status, message):
+        self.status = status
+        self.message = message
