@@ -1,7 +1,7 @@
 import hashlib
 import hmac
 import time
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Optional, Union
 
 import nautilus_trader
 from aiohttp import ClientConnectorError
@@ -19,14 +19,14 @@ def retry_if_connect_error(exception):
 
 class ZbSpotHttpClient(ZbHttpClient):
 
-    BASE_URL = "https://api.zb.company"  # market api
-    # BASE_URL = "https://trade.zb.company"  # trade api
+    BASE_URL = "https://api.zb.com"  # market api
+    # BASE_URL = "https://trade.zb.com"  # trade api
 
     async def sign_request(
         self,
         http_method: str,
         url_path: str,
-        payload: Dict[str, Any] = None,
+        payload: Optional[Dict[str, Any]] = None,
     ) -> Any:
         if payload is None:
             payload = {}
