@@ -1,6 +1,8 @@
+import time
 from decimal import Decimal
 from typing import Any, Dict, List, Optional, Tuple
 
+from nautilus_trader.common.providers import InstrumentProvider
 from nautilus_trader.core.datetime import millis_to_nanos
 from nautilus_trader.core.datetime import secs_to_nanos
 from nautilus_trader.core.uuid import UUID4
@@ -18,7 +20,9 @@ from nautilus_trader.model.enums import AggressorSide
 from nautilus_trader.model.enums import BarAggregation
 from nautilus_trader.model.enums import BookAction
 from nautilus_trader.model.enums import BookType
+from nautilus_trader.model.enums import CurrencyType
 from nautilus_trader.model.enums import LiquiditySide
+from nautilus_trader.model.enums import OMSType
 from nautilus_trader.model.enums import OrderSide
 from nautilus_trader.model.enums import OrderStatus
 from nautilus_trader.model.enums import OrderType
@@ -29,9 +33,13 @@ from nautilus_trader.model.identifiers import AccountId
 from nautilus_trader.model.identifiers import ClientOrderId
 from nautilus_trader.model.identifiers import InstrumentId
 from nautilus_trader.model.identifiers import PositionId
+from nautilus_trader.model.identifiers import Symbol
 from nautilus_trader.model.identifiers import TradeId
+from nautilus_trader.model.identifiers import Venue
 from nautilus_trader.model.identifiers import VenueOrderId
 from nautilus_trader.model.instruments.base import Instrument
+from nautilus_trader.model.instruments.crypto_perpetual import CryptoPerpetual
+from nautilus_trader.model.instruments.currency_pair import CurrencyPair
 from nautilus_trader.model.objects import AccountBalance
 from nautilus_trader.model.objects import MarginBalance
 from nautilus_trader.model.objects import Money
@@ -47,11 +55,7 @@ from nautilus_trader.model.position import Position
 
 from nacre.adapters.zb.data_types import ZbBar
 from nacre.adapters.zb.data_types import ZbTicker
-from nacre.adapters.zb.providers import ZbInstrumentProvider
 from nacre.model.data.tick import MarkTick
-from nacre.model.report_position import ReportedPosition
-from nacre.model.report_position import SideWithMode
-from nacre.model.report_position import WalletBalance
 
 
 def parse_mark_price(instrument_id: InstrumentId, price: str, ts_init: int) -> MarkTick:
@@ -218,7 +222,7 @@ def parse_trade_tick_ws(instrument_id: InstrumentId, msg: List, ts_init: int) ->
         price=Price.from_str(str(msg[0])),
         size=Quantity.from_str(str(msg[1])),
         aggressor_side=AggressorSide.SELL if msg[2] == -1 else AggressorSide.BUY,
-        trade_id=str(msg[3]),
+        trade_id=TradeId(str(msg[3])),
         # ts_event=secs_to_nanos(float(msg[3])),  # zb time not accurate
         ts_event=ts_init,
         ts_init=ts_init,
@@ -424,11 +428,18 @@ def parse_position(
     report_id: UUID4,
     ts_init: int,
 ) -> PositionStatusReport:
+    if data["side"] == 2:
+        position_side = PositionSide.LONG if data["nominalValue"] > 0 else PositionSide.SHORT
+    elif data["side"] == 1:
+        position_side = PositionSide.LONG
+    else:  # data["side"] == 0:
+        position_side = PositionSide.SHORT
+
     return PositionStatusReport(
         account_id=account_id,
         instrument_id=instrument.id,
-        position_side=PositionSide.LONG if data["side"] == 1 else PositionSide.SHORT,
-        venue_position_id=PositionId(data["id"]),
+        position_side=position_side,
+        venue_position_id=PositionId(data["id"]),  # FIX: not same with self-generated position_id
         quantity=instrument.make_qty(data["amount"]),
         report_id=report_id,
         ts_last=ts_init,
@@ -439,42 +450,6 @@ def parse_position(
 # Account parsing
 
 
-def parse_positions(positions: List[Dict[str, Any]]) -> List[Dict]:
-    results = []
-    for po in positions:
-        # Zb future currently only support dual side
-        # if po["positionsMode"] == 1:
-        #     position_side = "BOTH"
-        if po["side"] == 1:
-            position_side = "LONG"
-        elif po["side"] == 0:
-            position_side = "SHORT"
-        else:
-            raise ValueError(f"not recognized side {po['side']}")
-
-        notional = float(po["nominalValue"])
-        position = dict(
-            id=po["id"],
-            sym=po["marketName"],
-            qty=float(po["amount"]),
-            notional=notional if po["side"] == 1 else -1 * notional,
-            ep=float(po["avgPrice"]),  # entry price
-            lp=float(po["liquidatePrice"]),  # liquidate Price
-            upnl=float(po["unrealizedPnl"]),  # unrealized pnl
-            mt="isolated" if po["marginMode"] == 1 else "cross",  # margin type
-            ps=position_side,  # position side
-            lg=int(po["leverage"]),
-            # im=float(po["initialMargin"]),  # initial margin
-            mm=float(po["maintainMargin"]),  # maintenance margin
-            mr=float(po["marginRate"]),  # margin rate
-            # pim=float(po["positionInitialMargin"]),  # position Initial Margin
-            m=float(po["margin"]),  # margin
-            mb=float(po["marginBalance"]),  # margin balance
-        )
-        results.append(position)
-    return results
-
-
 def parse_zb_spot_liquidity_side(side: int) -> OrderSide:
     if side >= 4:  # IOC
         return LiquiditySide.TAKER
@@ -502,7 +477,7 @@ def parse_spot_account_balances_raw(provider, raw_balances: List) -> List[Accoun
 
 
 def _parse_balances(
-    provider: ZbInstrumentProvider,
+    provider: InstrumentProvider,
     raw_balances: List[Dict[str, str]],
     asset_key: str,
     free_key: str,
@@ -550,65 +525,6 @@ def parse_account_margins_raw(provider, raw_margins: List[Dict]) -> List[MarginB
 
 
 # ZB future use USDT as default
-def parse_reported_wallet_balances(provider, raws: List[Dict]) -> List[WalletBalance]:
-    wbs = []
-    for raw in raws:
-        wb = parse_reported_wallet_balance(provider, raw)
-        wbs.append(wb)
-    return wbs
-
-
-def parse_reported_wallet_balance(provider, raw: Dict) -> WalletBalance:
-    currency = provider.currency(raw["unit"].upper())
-
-    total = Decimal(raw["accountBalance"])
-    margin = Decimal(raw["allMargin"])
-    maint_margin = Decimal(raw["freeze"])
-
-    return WalletBalance(
-        asset=currency,
-        total=total,
-        margin=margin,
-        maint_margin=maint_margin,
-    )
-
-
-def parse_reported_position(provider, raw_positions: List) -> List[ReportedPosition]:
-    positions = []
-    for po in raw_positions:
-        symbol: str = po["marketName"]
-        instrument_id = provider.find_instrument_id_by_local_symbol(symbol)
-
-        # Zb currently only support Hedge mode
-        # zb_position_mode = po["positionsMode"]
-        # if zb_position_mode == 1:  # One way / Both
-        #     side = SideWithMode.BOTH
-        # else:  # zb_position_mode == 2:  # Hedge Mode
-        if po["side"] == 1:
-            side = SideWithMode.LONG
-        elif po["side"] == 0:
-            side = SideWithMode.SHORT
-        else:
-            raise ValueError(f"not recognized side {po['side']}")
-
-        sign = 1 if po["side"] > 0 else -1
-        net_qty = sign * Decimal(po["amount"])
-
-        position = ReportedPosition(
-            instrument_id=instrument_id,
-            position_id=PositionId(po["id"]),
-            side=side,
-            net_qty=net_qty,
-            multiplier=int(po["leverage"]),
-            avg_px_open=Decimal(po["avgPrice"]),
-            unrealized_pnl=Decimal(po["unrealizedPnl"]),
-            margin=Decimal(po["marginBalance"]),
-            maint_margin=Decimal(po["maintainMargin"]),
-            liquidity_px=Decimal(po["liquidatePrice"]),
-        )
-
-        positions.append(position)
-    return positions
 
 
 def parse_zb_position_side(side: int) -> PositionSide:
@@ -634,22 +550,43 @@ def parse_zb_order_type(action: int) -> OrderType:
         return OrderType.LIMIT
 
 
-def zb_order_side(order: Order, position: Optional[Position] = None) -> int:
+def zb_order_side(  # noqa: C901
+    order: Order, oms_type: OMSType, position: Optional[Position] = None
+) -> int:
     if order.side == OrderSide.BUY:
-        if not position:
-            return 1
-        return 1 if position.side == PositionSide.LONG else 4
-    else:  # order.side == OrderSide.SELL
-        if not position:
-            return 2
-        return 3 if position.side == PositionSide.LONG else 2
+        if oms_type == OMSType.NETTING:
+            if order.is_reduce_only:
+                return 0
+            else:
+                return 5
+        elif oms_type == OMSType.HEDGING:
+            # Closing short position
+            if position is not None and position.side == PositionSide.SHORT:
+                return 4
+            else:
+                return 1
+    elif order.side == OrderSide.SELL:
+        if oms_type == OMSType.NETTING:
+            if order.is_reduce_only:
+                return 0
+            else:
+                return 6
+        elif oms_type == OMSType.HEDGING:
+            # Closing long position
+            if position is not None and position.side == PositionSide.LONG:
+                return 3
+            else:
+                return 2
+    raise ValueError(f"Unsupported oms type {oms_type}")
 
 
-def zb_order_params(order: Order, position: Optional[Position] = None) -> Dict[str, Any]:
+def zb_order_params(
+    order: Order, oms_type: OMSType, position: Optional[Position] = None
+) -> Dict[str, Any]:
     if order.type == OrderType.MARKET:
         return dict(
             symbol=order.instrument_id.symbol.value,
-            side=zb_order_side(order, position),
+            side=zb_order_side(order, oms_type, position),
             amount=order.quantity.as_double(),
             action=zb_order_action_market(order),
             client_order_id=order.client_order_id.value,
@@ -657,7 +594,7 @@ def zb_order_params(order: Order, position: Optional[Position] = None) -> Dict[s
     elif order.type == OrderType.LIMIT:
         return dict(
             symbol=order.instrument_id.symbol.value,
-            side=zb_order_side(order, position),
+            side=zb_order_side(order, oms_type, position),
             amount=order.quantity.as_double(),
             action=zb_order_action_limit(order),
             price=order.price.as_double(),
@@ -690,3 +627,138 @@ def zb_order_action_limit(order: LimitOrder) -> int:
         return 5
     else:
         raise ValueError(f"Unsupported time_in_force limit for zb: {order.time_in_force}")
+
+
+def _quote_precision(quote_asset: str) -> int:
+    #  common quotes are ("ZUSD", "USDT", "QC", "BTC", "USDC"):
+    return 8  # hardcode for now
+
+
+def parse_future_instrument_http(market: Dict, venue: Venue) -> Instrument:
+    # Create base asset
+    base_asset = market["sellerCurrencyName"].upper()
+    base_currency = Currency(
+        code=base_asset,
+        precision=int(market["priceDecimal"]),
+        iso4217=0,  # Currently undetermined for crypto assets
+        name=base_asset,
+        currency_type=CurrencyType.CRYPTO,
+    )
+
+    # Create quote asset
+    quote_asset = market["buyerCurrencyName"].upper()
+    quote_currency = Currency(
+        code=quote_asset,
+        precision=_quote_precision(quote_asset),
+        iso4217=0,  # Currently undetermined for crypto assets
+        name=quote_asset,
+        currency_type=CurrencyType.CRYPTO,
+    )
+
+    symbol = Symbol(base_currency.code + "/" + quote_currency.code)
+    # symbol = Symbol(market["symbol"])
+    instrument_id = InstrumentId(symbol=symbol, venue=venue)
+
+    # NOTE: ZB api doesn't provide info about tick size, simulate using price_precision
+    price_increment = Price(
+        value=1 / (10 ** int(market["priceDecimal"])), precision=int(market["priceDecimal"])
+    )
+    size_increment = Quantity(
+        value=1 / (10 ** int(market["amountDecimal"])),
+        precision=int(market["amountDecimal"]),
+    )
+
+    # TODO: query vip status programmatically
+    # default fee rate is 0.075% for taker, 0.025% for vip taker
+    # default fee rate is 0 for maker, -0.025% for vip maker
+    maker_fee: Decimal = Decimal("-0.00025")  # vip
+    taker_fee: Decimal = Decimal("0.00025")  # vip
+    # maker_fee: Decimal = Decimal(0)
+    # taker_fee: Decimal = Decimal("0.00075")
+
+    return CryptoPerpetual(
+        instrument_id=instrument_id,
+        native_symbol=Symbol(market["symbol"]),
+        base_currency=base_currency,
+        quote_currency=quote_currency,
+        settlement_currency=quote_currency,  # for USDT-based markets, settlement == quote
+        is_inverse=False,
+        price_precision=int(market["priceDecimal"]),
+        size_precision=int(market["amountDecimal"]),
+        price_increment=price_increment,
+        size_increment=size_increment,
+        max_quantity=Quantity(market["maxAmount"], int(market["amountDecimal"])),
+        min_quantity=Quantity(market["minAmount"], int(market["amountDecimal"])),
+        max_notional=None,
+        min_notional=Money(market["minTradeMoney"], currency=quote_currency),
+        max_price=None,
+        min_price=None,
+        margin_init=Decimal(0),
+        margin_maint=Decimal(0),
+        maker_fee=maker_fee,
+        taker_fee=taker_fee,
+        ts_event=time.time_ns(),
+        ts_init=time.time_ns(),
+        info=market,
+    )
+
+
+def parse_spot_instrument_http(market: str, entry: Dict, venue: Venue):
+    base, _, quote = market.partition("_")
+
+    # Create base asset
+    base_asset = base.upper()
+    base_currency = Currency(
+        code=base_asset,
+        precision=4,  # Hardcoded for zb spot
+        iso4217=0,  # Currently undetermined for crypto assets
+        name=base_asset,
+        currency_type=CurrencyType.CRYPTO,
+    )
+
+    # Create quote asset
+    quote_asset = quote.upper()
+    quote_currency = Currency(
+        code=quote_asset,
+        precision=_quote_precision(quote_asset),
+        iso4217=0,  # Currently undetermined for crypto assets
+        name=quote_asset,
+        currency_type=CurrencyType.CRYPTO,
+    )
+
+    symbol = Symbol(base_currency.code + "/" + quote_currency.code)
+    instrument_id = InstrumentId(symbol=symbol, venue=venue)
+
+    price_increment = Price(
+        value=1 / (10 ** int(entry["priceScale"])),
+        precision=int(entry["priceScale"]),
+    )
+    size_increment = Quantity(
+        value=1 / (10 ** int(entry["amountScale"])),
+        precision=int(entry["amountScale"]),
+    )
+
+    return CurrencyPair(
+        instrument_id=instrument_id,
+        native_symbol=Symbol(market),
+        base_currency=base_currency,
+        quote_currency=quote_currency,
+        price_precision=int(entry["priceScale"]),
+        size_precision=int(entry["amountScale"]),
+        price_increment=price_increment,
+        size_increment=size_increment,
+        lot_size=None,
+        max_quantity=None,
+        min_quantity=Quantity(entry["minAmount"], int(entry["minAmount"])),
+        max_notional=None,
+        min_notional=None,
+        max_price=None,
+        min_price=None,
+        margin_init=Decimal(0),
+        margin_maint=Decimal(0),
+        maker_fee=Decimal("0.002"),
+        taker_fee=Decimal("0.002"),
+        ts_event=time.time_ns(),
+        ts_init=time.time_ns(),
+        info=entry,
+    )
