@@ -1,8 +1,7 @@
 import asyncio
 from datetime import timedelta
-from typing import Callable, Dict
+from typing import Awaitable, Callable, Dict, List  # noqa: TYP001
 
-import orjson
 from aiohttp import ClientConnectorError
 from nautilus_trader.common.clock import LiveClock
 from nautilus_trader.common.logging import Logger
@@ -26,21 +25,38 @@ class ZbWebSocketClient(WebSocketClient):
         logger: Logger,
         handler: Callable[[bytes], None],
         base_url: str,
-        socks_proxy: str = None,
     ):
         super().__init__(
             loop=loop,
             logger=logger,
             handler=handler,
             max_retry_connection=5,
-            socks_proxy=socks_proxy,
         )
 
         self._base_url = base_url
         self._clock = clock
-        self._subscriptions: Dict = {}
+        self._subscriptions: Dict[str, Dict] = {}
         self._pager_name = None
 
+        self._post_connect_callbacks: List[Awaitable] = []
+
+    def add_post_connect_callbacks(self, *callbacks: Awaitable):
+        self._post_connect_callbacks.extend(callbacks)
+
+    async def post_connection(self):
+        # Multiple writer should exist in other tasks
+        # Ref: https://docs.aiohttp.org/en/stable/client_quickstart.html#websockets
+        self._loop.create_task(self._post_connection())
+
+    async def post_reconnection(self):
+        self._loop.create_task(self._post_connection())
+
+    async def _post_connection(self):
+        if self._pager_name is None:
+            self._set_up_pager()
+
+        await self.on_post_connect()
+
     def _set_up_pager(self):
         self._pager_name = UUIDFactory().generate().value
         self._clock.set_timer(
@@ -55,32 +71,29 @@ class ZbWebSocketClient(WebSocketClient):
         self._loop.create_task(self.ping())
 
     async def ping(self):
-        await self.send(orjson.dumps({"action": "ping"}))
-
-    async def post_connect(self):
-        # Multiple writer should exist in other tasks
-        # Ref: https://docs.aiohttp.org/en/stable/client_quickstart.html#websockets
-        self._loop.create_task(self._post_connect())
-
-    async def _post_connect(self):
-        if self._pager_name is None:
-            self._set_up_pager()
-
-        await self.on_post_connect()
+        if not self.retrying:
+            try:
+                await self.send_json({"action": "ping"})
+            except ConnectionResetError:
+                return
 
     async def on_post_connect(self):
-        """Abstract method (implement in subclass)."""
-        raise NotImplementedError("method must be implemented in the subclass")  # pragma: no cover
+        # Resubscribe when reconnect
+        if self._subscriptions:
+            await self._resubscribe()
 
-    async def post_disconnect(self):
+        for callback_routine in self._post_connect_callbacks:
+            await callback_routine
+
+    async def post_disconnection(self):
         if self._pager_name:
             self._clock.cancel_timer(self._pager_name)
             self._pager_name = None
 
     async def _resubscribe(self):
-        for channel, subscription in self._subscriptions.items():
-            self._log.debug(f"Resubscribe channel {channel} ... {subscription}")
-            await self.send(orjson.dumps(subscription))
+        for subscription in self._subscriptions.values():
+            self._log.debug(f"Resubscribe {subscription}")
+            await self.send_json(subscription)
 
     @retry(retry=retry_if_exception_type(ClientConnectorError))
     async def connect(self, start: bool = True, **ws_kwargs) -> None:
@@ -92,21 +105,35 @@ class ZbWebSocketClient(WebSocketClient):
             self._log.warning(f"{ex}, Retrying...")
             raise ex
 
+    # One time request
+    async def _request_channel(self, channel: str, **kwargs):
+        payload = {"channel": channel}
+        if kwargs:
+            payload.update(kwargs)
+        await self._send_ws_request(payload)
+
+    # Subscription continues to push when state change
     async def _subscribe_channel(self, channel: str, **kwargs):
         payload = {"channel": channel}
         if kwargs:
             payload.update(kwargs)
 
-        self._subscriptions[channel] = payload
-        while not self.is_connected:
-            await self._sleep0()
-
-        await self.send(orjson.dumps(payload))
+        # Resubscribe when reconnect
+        hash_key = str(payload.values())
+        self._subscriptions[hash_key] = payload
+        await self._send_ws_request(payload)
 
+    # Not tested
     async def _unsubscribe_channel(self, channel: str, **kwargs):
         payload = {"channel": channel}
         if kwargs:
             payload.update(kwargs)
 
         self._subscriptions.pop(channel, None)
-        await self.send(orjson.dumps(payload))
+        await self._send_ws_request(payload)
+
+    async def _send_ws_request(self, payload: dict):
+        while not self.is_connected:
+            await self._sleep0()
+
+        await self.send_json(payload)
