@@ -5,12 +5,15 @@ from typing import Dict, Optional
 
 import fire
 import yaml  # type: ignore
-from nautilus_trader.trading.config import ImportableStrategyConfig
-from nautilus_trader.trading.config import StrategyFactory
+from nautilus_trader.common.actor import Actor
+from nautilus_trader.config import ActorFactory
+from nautilus_trader.config import ImportableActorConfig
+from nautilus_trader.config import ImportableStrategyConfig
+from nautilus_trader.config import StrategyFactory
+from nautilus_trader.live.node import TradingNode
 from nautilus_trader.trading.strategy import TradingStrategy
 
-from nacre.live.node import TradingNode
-from nacre.live.node import TradingNodeConfig
+from nacre.config import TradingNodeConfig
 
 
 def run():
@@ -21,9 +24,6 @@ def run_live_node(config: str, log_path: Optional[str] = None, credential_path:
     with open(config, "r") as stream:
         node_cfg = yaml.safe_load(stream)
 
-    if "strategies" not in node_cfg:
-        return "strategy not specified"
-
     # redirect log
     if log_path is None and "log_path" in node_cfg:
         log_path = node_cfg.pop("log_path")
@@ -42,10 +42,16 @@ def run_live_node(config: str, log_path: Optional[str] = None, credential_path:
 
     factories_cfg = node_cfg.pop("factories")
 
+    # initialize actors
+    actors = [_build_actor(actor_config) for actor_config in node_cfg.pop("actors", [])]
     # initialize strategies
-    strategies = [_build_strategy(strategy) for strategy in node_cfg.pop("strategies")]
-    node = TradingNode(config=TradingNodeConfig(**node_cfg))
-    node.trader.add_strategies(strategies)
+    strategies = [_build_strategy(strategy) for strategy in node_cfg.pop("strategies", [])]
+
+    node = TradingNode(config=TradingNodeConfig.parse_obj(node_cfg))
+    if actors:
+        node.trader.add_actors(actors)
+    if strategies:
+        node.trader.add_strategies(strategies)
 
     # apply factories
     _add_client_factories(node, factories_cfg)
@@ -75,15 +81,21 @@ def _add_client_factories(node: TradingNode, config: Dict):
             node.add_exec_client_factory(venue, _import_cls(path))
 
 
-def _build_strategy(config: Dict) -> TradingStrategy:
-    stra_config_cls = _import_cls(config.pop("config_path"))
-    stra_config = stra_config_cls(**config.pop("config"))
+def _build_actor(actor: Dict) -> Actor:
+    config = ImportableActorConfig(**actor)
+    return ActorFactory.create(config)
 
-    isc = ImportableStrategyConfig(path=config["path"], config=stra_config)
-    return StrategyFactory.create(isc)
+
+def _build_strategy(strategy: Dict) -> TradingStrategy:
+    config = ImportableStrategyConfig(**strategy)
+    return StrategyFactory.create(config)
 
 
 def _load_credentials(node_cfg: Dict, credential_path: str) -> None:
+    """
+    Fulfill exec_clients with exec_client_ids
+
+    """
     exec_clients = node_cfg.get("exec_clients", {})
     exec_client_ids = node_cfg.pop("exec_client_ids", None)
     if not exec_client_ids:
@@ -94,6 +106,8 @@ def _load_credentials(node_cfg: Dict, credential_path: str) -> None:
         for id, settings in exec_client_ids.items():
             main_venue, _, account_id = id.partition("-")
             creds = account_credentials.get(id, {})
+
+            # For each exec_client_id generate SPOT and FUTURE exec_client separately
             for account_type in ("SPOT", "FUTURE"):
                 client_id = f"{main_venue}_{account_type}-{account_id}"
                 override_settings = {"defaultType": account_type.lower(), **creds, **settings}
