@@ -1,17 +1,17 @@
 from nautilus_trader.model.data.base import DataType
 from nautilus_trader.model.identifiers import ClientId
 from nautilus_trader.model.identifiers import Venue
-from nautilus_trader.trading.strategy import TradingStrategy
-from nautilus_trader.trading.strategy import TradingStrategyConfig
+from nautilus_trader.trading.strategy import Strategy
+from nautilus_trader.trading.strategy import StrategyConfig
 
 from nacre.model.data.tick import MarkTick
 
 
-class MonConfig(TradingStrategyConfig):
+class MonConfig(StrategyConfig):
     venues: str  # separate by comma
 
 
-class Mon(TradingStrategy):
+class Mon(Strategy):
     def __init__(self, config: MonConfig):
         super().__init__(config)
         self.venues = [Venue(v) for v in config.venues.split(",")]
